runGlassExample: Run a built-in glasstabs example app

View source: R/dependencies.R

runGlassExampleR Documentation

Run a built-in glasstabs example app

Description

Launches one of the example Shiny apps that ship with the package. A list of available examples is printed when called with no arguments. Example apps are launched only in interactive sessions.

Usage

runGlassExample(example = NULL, ...)

Arguments

example

Name of the example to run, such as "basic", "bslib", "connect-workflow", "dashboard", "indicators", "server-select", "smoke-test", or "square-corners". When NULL (default), lists all available examples.

...

Additional arguments passed to shiny::runApp().

Value

Called for its side-effect (launches a Shiny app).

Examples

# List available examples
runGlassExample()

# Run an example interactively
if (interactive()) {
  runGlassExample("bslib")
  runGlassExample("connect-workflow")
  runGlassExample("smoke-test")
  runGlassExample("server-select")
}


glasstabs documentation built on Sept. 11, 2026, 5:08 p.m.