Skip to contents

Create a custom color theme for glassMultiSelect

Usage

glass_select_theme(
  bg_color = NULL,
  border_color = NULL,
  text_color = NULL,
  accent_color = NULL
)

Arguments

bg_color

Background color of the trigger button and dropdown panel.

border_color

Border color.

text_color

Main text color.

accent_color

Accent color used for the animated tick, badge, checked-state highlights, and the "Clear all" link.

Value

A named list of class "glass_select_theme".