Prints the package NEWS to the R console. Useful for quickly checking what changed between versions without leaving your R session.
Examples
if (interactive()) {
glasstabs_news()
}
Prints the package NEWS to the R console. Useful for quickly checking what changed between versions without leaving your R session.
if (interactive()) {
glasstabs_news()
}