Launches one of the example Shiny apps that ship with the package. A list of available examples is printed when called with no arguments. Example apps are launched only in interactive sessions.
Arguments
- example
Name of the example to run, such as
"basic","bslib","connect-workflow","dashboard","indicators","server-select","smoke-test", or"square-corners". WhenNULL(default), lists all available examples.- ...
Additional arguments passed to
shiny::runApp().
Examples
# List available examples
runGlassExample()
#> Available glasstabs examples:
#> - basic
#> - bs4dash
#> - bslib
#> - connect-workflow
#> - dashboard
#> - indicators
#> - server-select
#> - smoke-test
#> - square-corners
#>
#> Run one with: runGlassExample("basic")
# Run an example interactively
if (interactive()) {
runGlassExample("bslib")
runGlassExample("connect-workflow")
runGlassExample("smoke-test")
runGlassExample("server-select")
}