| runGlassExample | R Documentation |
Launches one of the example Shiny apps that ship with the package. A list of available examples is printed when called with no arguments. Example apps are launched only in interactive sessions.
runGlassExample(example = NULL, ...)
example |
Name of the example to run, such as |
... |
Additional arguments passed to |
Called for its side-effect (launches a Shiny app).
# List available examples
runGlassExample()
# Run an example interactively
if (interactive()) {
runGlassExample("bslib")
runGlassExample("connect-workflow")
runGlassExample("smoke-test")
runGlassExample("server-select")
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.